@@ -8,7 +8,7 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: ldap.c,v 1.62 2005/02/24 00:30:01 ca Exp $")
+SM_RCSID("@(#)$Id: ldap.c,v 1.65 2005/06/23 23:11:22 ca Exp $")
 
 #if LDAPMAP
 # include <sys/types.h>
@@ -615,6 +615,16 @@ sm_ldap_results(lmap, msgid, flags, delim, rpool, result,
 				continue;
 			}
 
+#if _FFR_LDAP_SINGLEDN
+			if (bitset(SM_LDAP_SINGLEDN, flags) && *result != NULL)
+			{
+				/* only wanted one match */
+				SM_LDAP_ERROR_CLEANUP();
+				errno = ENOENT;
+				return EX_NOTFOUND;
+			}
+#endif /* _FFR_LDAP_SINGLEDN */
+
 			/* record completed DN's to prevent loops */
 			dn = ldap_get_dn(lmap->ldap_ld, entry);
 			if (dn == NULL)
