@@ -13,13 +13,13 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: refill.c,v 1.50 2002/09/09 21:50:10 gshapiro Exp $")
+SM_RCSID("@(#)$Id: refill.c,v 1.51 2005/06/14 23:07:20 ca Exp $")
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
-#include <sys/time.h>
+#include <sm/time.h>
 #include <fcntl.h>
 #include <string.h>
 #include <sm/io.h>
